@@ -27,6 +27,7 @@
 #include "tqdbusdatalist.h"
 #include "tqdbusdatamap.h"
 #include "tqdbusobjectpath.h"
+#include "tqdbusunixfd.h"
 #include "tqdbusvariant.h"
 
 #include <tqvariant.h>
@@ -62,6 +63,7 @@ static TQT_DBusData::Type qSingleTypeForDBusSignature(char signature)
         case 'o': return TQT_DBusData::ObjectPath;
         case 'g': return TQT_DBusData::String;
         case 'v': return TQT_DBusData::Variant;
+        case 'h': return TQT_DBusData::UnixFd;
 
         default:
             break;
@@ -72,7 +74,7 @@ static TQT_DBusData::Type qSingleTypeForDBusSignature(char signature)
 
 static TQValueList<TQT_DBusData> parseSignature(TQCString& signature)
 {
-//    qDebug("parseSignature(%s)", signature.data());
+//    tqDebug("parseSignature(%s)", signature.data());
     TQValueList<TQT_DBusData> result;
 
     while (!signature.isEmpty())
@@ -133,8 +135,12 @@ static TQValueList<TQT_DBusData> parseSignature(TQCString& signature)
                             result << TQT_DBusData::fromObjectPathKeyMap(
                                 TQT_DBusDataMap<TQT_DBusObjectPath>(valueType));
                             break;
+                        case TQT_DBusData::UnixFd:
+                            result << TQT_DBusData::fromUnixFdKeyMap(
+                                TQT_DBusDataMap<TQT_DBusUnixFd>(valueType));
+                            break;
                         default:
-                            qWarning("TQT_DBusMarshall: unsupported map key type %s "
+                            tqWarning("TQT_DBusMarshall: unsupported map key type %s "
                                      "at de-marshalling",
                                      TQT_DBusData::typeName(keyType));
                             break;
@@ -186,8 +192,12 @@ static TQValueList<TQT_DBusData> parseSignature(TQCString& signature)
                             result << TQT_DBusData::fromObjectPathKeyMap(
                                 TQT_DBusDataMap<TQT_DBusObjectPath>(valueContainer[0]));
                             break;
+                        case TQT_DBusData::UnixFd:
+                            result << TQT_DBusData::fromUnixFdKeyMap(
+                                TQT_DBusDataMap<TQT_DBusUnixFd>(valueContainer[0]));
+                            break;
                         default:
-                            qWarning("TQT_DBusMarshall: unsupported map key type %s "
+                            tqWarning("TQT_DBusMarshall: unsupported map key type %s "
                                      "at de-marshalling",
                                      TQT_DBusData::typeName(keyType));
                             break;
@@ -227,8 +237,69 @@ static TQValueList<TQT_DBusData> parseSignature(TQCString& signature)
                 break;
             }
             default:
-                result << TQT_DBusData();
-                signature = signature.mid(1);
+                TQT_DBusData::Type elementType =
+                    qSingleTypeForDBusSignature(signature[0]);
+                if (elementType != TQT_DBusData::Invalid)
+                {
+                    switch (elementType)
+                    {
+                        case TQT_DBusData::Bool:
+                            result << TQT_DBusData::fromBool(
+                                (0));
+                            break;
+                        case TQT_DBusData::Byte:
+                            result << TQT_DBusData::fromByte(
+                                (0));
+                            break;
+                        case TQT_DBusData::Int16:
+                            result << TQT_DBusData::fromInt16(
+                                (0));
+                            break;
+                        case TQT_DBusData::UInt16:
+                            result << TQT_DBusData::fromUInt16(
+                                (0));
+                            break;
+                        case TQT_DBusData::Int32:
+                            result << TQT_DBusData::fromInt32(
+                                (0));
+                            break;
+                        case TQT_DBusData::UInt32:
+                            result << TQT_DBusData::fromUInt32(
+                                (0));
+                            break;
+                        case TQT_DBusData::Int64:
+                            result << TQT_DBusData::fromInt64(
+                                (0));
+                            break;
+                        case TQT_DBusData::UInt64:
+                            result << TQT_DBusData::fromUInt64(
+                                (0));
+                            break;
+                        case TQT_DBusData::String:
+                            result << TQT_DBusData::fromString(
+                                (TQString()));
+                            break;
+                        case TQT_DBusData::ObjectPath:
+                            result << TQT_DBusData::fromObjectPath(
+                                (TQT_DBusObjectPath()));
+                            break;
+                        case TQT_DBusData::UnixFd:
+                            result << TQT_DBusData::fromUnixFd(
+                                (TQT_DBusUnixFd()));
+                            break;
+                        default:
+                            result << TQT_DBusData();
+                            tqWarning("TQT_DBusMarshall: unsupported element type %s "
+                                     "at de-marshalling",
+                                     TQT_DBusData::typeName(elementType));
+                            break;
+                    }
+                    signature = signature.mid(1);
+                }
+                else {
+                    result << TQT_DBusData();
+                    signature = signature.mid(1);
+                }
                 break;
         }
     }
@@ -528,6 +599,11 @@ static TQT_DBusData qFetchParameter(DBusMessageIter *it)
 
         return TQT_DBusData::fromStruct(memberList);
     }
+    case DBUS_TYPE_UNIX_FD: {
+        TQT_DBusUnixFd unixFd;
+        unixFd.giveFileDescriptor(qIterGet<dbus_uint32_t>(it));
+        return TQT_DBusData::fromUnixFd(unixFd);
+    }
 #if 0
     case DBUS_TYPE_INVALID:
         // TODO: check if there is better way to detect empty arrays
@@ -535,7 +611,7 @@ static TQT_DBusData qFetchParameter(DBusMessageIter *it)
         break;
 #endif
     default:
-        qWarning("TQT_DBusMarshall: Don't know how to de-marshall type %d '%c'",
+        tqWarning("TQT_DBusMarshall: Don't know how to de-marshall type %d '%c'",
                  dbus_message_iter_get_arg_type(it),
                  dbus_message_iter_get_arg_type(it));
         return TQT_DBusData();
@@ -570,6 +646,12 @@ static void tqAppendToMessage(DBusMessageIter *it, const TQT_DBusObjectPath &pat
     dbus_message_iter_append_basic(it, DBUS_TYPE_OBJECT_PATH, &cdata);
 }
 
+static void tqAppendToMessage(DBusMessageIter *it, const TQT_DBusUnixFd &unixFd)
+{
+    const dbus_int32_t cdata = unixFd.fileDescriptor();
+    dbus_message_iter_append_basic(it, DBUS_TYPE_UNIX_FD, &cdata);
+}
+
 static const char* qDBusTypeForTQT_DBusType(TQT_DBusData::Type type)
 {
     switch (type)
@@ -621,6 +703,9 @@ static const char* qDBusTypeForTQT_DBusType(TQT_DBusData::Type type)
 
         case TQT_DBusData::Map:
             return DBUS_TYPE_DICT_ENTRY_AS_STRING;
+
+        case TQT_DBusData::UnixFd:
+            return DBUS_TYPE_UNIX_FD_AS_STRING;
     }
     return 0;
 }
@@ -934,6 +1019,40 @@ static void qDBusObjectPathKeyMapToIterator(DBusMessageIter* it,
     dbus_message_iter_close_container(it, &sub);
 }
 
+static void qDBusUnixFdKeyMapToIterator(DBusMessageIter* it, const TQT_DBusData& var)
+{
+    DBusMessageIter sub;
+    TQCString sig;
+
+    TQT_DBusDataMap<TQT_DBusUnixFd> map = var.toUnixFdKeyMap();
+
+    sig += DBUS_DICT_ENTRY_BEGIN_CHAR;
+    sig += qDBusTypeForTQT_DBusType(map.keyType());
+
+    if (map.hasContainerValueType())
+        sig += map.containerValueType().buildDBusSignature();
+    else
+        sig += qDBusTypeForTQT_DBusType(map.valueType());
+    sig += DBUS_DICT_ENTRY_END_CHAR;
+
+    dbus_message_iter_open_container(it, DBUS_TYPE_ARRAY, sig.data(), &sub);
+
+    TQT_DBusDataMap<TQT_DBusUnixFd>::const_iterator mit = map.begin();
+    for (; mit != map.end(); ++mit)
+    {
+        DBusMessageIter itemIterator;
+        dbus_message_iter_open_container(&sub, DBUS_TYPE_DICT_ENTRY,
+                                         0, &itemIterator);
+
+        dbus_message_iter_append_basic(it, DBUS_TYPE_UNIX_FD, &(mit.key()));
+        qDBusDataToIterator(&itemIterator, mit.data());
+
+        dbus_message_iter_close_container(&sub, &itemIterator);
+    }
+
+    dbus_message_iter_close_container(it, &sub);
+}
+
 static void qDBusDataToIterator(DBusMessageIter* it, const TQT_DBusData& var)
 {
     switch (var.type())
@@ -991,6 +1110,10 @@ static void qDBusDataToIterator(DBusMessageIter* it, const TQT_DBusData& var)
         case TQT_DBusData::ObjectPath:
             tqAppendToMessage(it, var.toObjectPath());
             break;
+        case TQT_DBusData::UnixFd: {
+            tqAppendToMessage(it, var.toUnixFd());
+            break;
+        }
         case TQT_DBusData::List: {
             TQT_DBusDataList list = var.toList();
 
@@ -1043,8 +1166,11 @@ static void qDBusDataToIterator(DBusMessageIter* it, const TQT_DBusData& var)
                 case TQT_DBusData::ObjectPath:
                     qDBusObjectPathKeyMapToIterator(it, var);
                     break;
+                case TQT_DBusData::UnixFd:
+                    qDBusUnixFdKeyMapToIterator(it, var);
+                    break;
                 default:
-                    qWarning("TQT_DBusMarshall: unhandled map key type %s "
+                    tqWarning("TQT_DBusMarshall: unhandled map key type %s "
                              "at marshalling",
                              TQT_DBusData::typeName(var.keyType()));
                     break;
@@ -1092,7 +1218,7 @@ static void qDBusDataToIterator(DBusMessageIter* it, const TQT_DBusData& var)
         }
 #endif
         default:
-            //qWarning("Don't know how to handle type %s", var.typeName());
+            //tqWarning("Don't know how to handle type %s", var.typeName());
             break;
     }
 }
