@@ -1251,7 +1251,9 @@ void MessageComposer::composeInlineOpenPGPMessage( KMMessage& theMessage,
     }
     mOldBodyPart.setContentDisposition( "inline" );
     mOldBodyPart.setOriginalContentTypeStr( oldContentType.utf8() );
-    mOldBodyPart.setCharset(mCharset);
+    if (mOldBodyPart.type() == DwMime::kTypeText) {
+      mOldBodyPart.setCharset(mCharset);
+    }
     addBodyAndAttachments( msg, splitInfo, false, false, mOldBodyPart, Kleo::InlineOpenPGPFormat );
     mMessageList.push_back( msg );
     if ( it == splitInfos.begin() ) {
