@@ -15,13 +15,6 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-    --------------------------------------------------------------
-    Additional changes:
-    - 2013/10/17 Michele Calgaro
-      * add "scroll tabs on mouse wheel event" functionality
-      * add support for updating options at runtime (no need to restart Konqueror
-        or reload the profile
 */
 
 #include "konq_viewmgr.h"
