@@ -93,7 +93,6 @@ public:
 	int stage;
 
 	//Protocol specific data
-	bool isIcq;
 	bool redirectRequested;
 	TQValueList<WORD> redirectionServices;
     WORD currentRedirect;
@@ -146,9 +145,8 @@ Client::Client( TQObject* parent )
 	d = new ClientPrivate;
 	d->tzoffset = 0;
 	d->active = false;
-	d->isIcq = false; //default to AIM
 	d->redirectRequested = false;
-    d->currentRedirect = 0;
+	d->currentRedirect = 0;
 	d->connectAsStatus = 0x0; // default to online
 	d->ssiManager = new SSIManager( this );
 	d->settings = new Oscar::Settings();
@@ -233,30 +231,6 @@ void Client::close()
     d->ssiManager->clear();
 }
 
-void Client::setStatus( AIMStatus status, const TQString &_message )
-{
-	// AIM: you're away exactly when your away message isn't empty.
-	// can't use TQString() as a message either; ProfileTask
-	// interprets null as "don't change".
-	TQString message;
-	if ( status == Online )
-		message = TQString::fromAscii("");
-	else
-	{
-		if ( _message.isEmpty() )
-			message = TQString::fromAscii(" ");
-		else
-			message = _message;
-	}
-
-	Connection* c = d->connections.connectionForFamily( 0x0002 );
-	if ( !c )
-		return;
-	ProfileTask* pt = new ProfileTask( c->rootTask() );
-	pt->setAwayMessage( message );
-	pt->go( true );
-}
-
 void Client::setStatus( DWORD status, const TQString &message )
 {
 	// remember the message to reply with, when requested
@@ -398,24 +372,21 @@ void Client::serviceSetupFinished()
 {
 	d->active = true;
 
-	if ( isIcq() )
-		setStatus( d->connectAsStatus, d->connectWithMessage );
+	setStatus( d->connectAsStatus, d->connectWithMessage );
 
 	d->ownStatusTask->go();
 
-	if ( isIcq() )
-	{
-		//retrieve offline messages
-		Connection* c = d->connections.connectionForFamily( 0x0015 );
-		if ( !c )
-			return;
-
-		OfflineMessagesTask *offlineMsgTask = new OfflineMessagesTask( c->rootTask() );
-		connect( offlineMsgTask, TQT_SIGNAL( receivedOfflineMessage(const Oscar::Message& ) ),
-				this, TQT_SIGNAL( messageReceived(const Oscar::Message& ) ) );
-		offlineMsgTask->go( true );
+	//retrieve offline messages
+	Connection* c = d->connections.connectionForFamily( 0x0015 );
+	if ( !c ) {
+		return;
 	}
 
+	OfflineMessagesTask *offlineMsgTask = new OfflineMessagesTask( c->rootTask() );
+	connect( offlineMsgTask, TQT_SIGNAL( receivedOfflineMessage(const Oscar::Message& ) ),
+			this, TQT_SIGNAL( messageReceived(const Oscar::Message& ) ) );
+	offlineMsgTask->go( true );
+
 	emit haveSSIList();
 	emit loggedIn();
 }
@@ -595,16 +566,6 @@ bool Client::isActive() const
 	return d->active;
 }
 
-bool Client::isIcq() const
-{
-	return d->isIcq;
-}
-
-void Client::setIsIcq( bool isIcq )
-{
-	d->isIcq = isIcq;
-}
-
 void Client::debug( const TQString& str )
 {
 	Q_UNUSED(str);
@@ -852,16 +813,6 @@ void Client::setChatExchangeList( const TQValueList<int>& exchanges )
 	d->exchanges = exchanges;
 }
 
-void Client::requestAIMProfile( const TQString& contact )
-{
-	d->userInfoTask->requestInfoFor( contact, UserInfoTask::Profile );
-}
-
-void Client::requestAIMAwayMessage( const TQString& contact )
-{
-	d->userInfoTask->requestInfoFor( contact, UserInfoTask::AwayMessage );
-}
-
 void Client::requestICQAwayMessage( const TQString& contact, ICQStatus contactStatus )
 {
 	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "requesting away message for " << contact << endl;
@@ -993,16 +944,6 @@ void Client::uinSearch( const TQString& uin )
 	ust->searchUserByUIN( uin );
 }
 
-void Client::updateProfile( const TQString& profile )
-{
-	Connection* c = d->connections.connectionForFamily( 0x0002 );
-	if ( !c )
-		return;
-	ProfileTask* pt = new ProfileTask( c->rootTask() );
-	pt->setProfileText( profile );
-	pt->go(true);
-}
-
 void Client::sendTyping( const TQString & contact, bool typing )
 {
 	Connection* c = d->connections.connectionForFamily( 0x0004 );
