@@ -999,7 +999,7 @@ void SimpleMainWindow::setCaption(const TQString &caption)
     {
         TQString projectname = project->projectName();
 
-        TQString suffix(".tdevelop");
+        TQString suffix(".kdevelop");
         if (projectname.endsWith(suffix))
             projectname.truncate(projectname.length() - suffix.length());
 
