@@ -350,30 +350,40 @@ int TQMYSQLResult::numRowsAffected()
 static void qServerEnd()
 {
 #ifndef Q_NO_MYSQL_EMBEDDED
-# if MYSQL_VERSION_ID >= 40000
+#if !defined(MARIADB_BASE_VERSION) && !defined(MARIADB_VERSION_ID)
+# if MYSQL_VERSION_ID > 40000
+#  if (MYSQL_VERSION_ID >= 40110 && MYSQL_VERSION_ID < 50000) || MYSQL_VERSION_ID >= 50003
+    mysql_library_end();
+#  else
     mysql_server_end();
-# endif // MYSQL_VERSION_ID
-#endif // Q_NO_MYSQL_EMBEDDED
+#  endif
+# endif
+#endif
+#endif
 }
 
 static void qServerInit()
 {
 #ifndef Q_NO_MYSQL_EMBEDDED
 # if MYSQL_VERSION_ID >= 40000
-    if ( qMySqlInitHandledByUser || qMySqlConnectionCount > 1 )
+    if (qMySqlInitHandledByUser || qMySqlConnectionCount > 1)
         return;
 
-    // this should only be called once
-    // has no effect on client/server library
-    // but is vital for the embedded lib
-    if ( mysql_server_init( 0, 0, 0 ) ) {
-#  ifdef QT_CHECK_RANGE
-	tqWarning( "TQMYSQLDriver::qServerInit: unable to start server." );
-#  endif
+    if (
+# if (MYSQL_VERSION_ID >= 40110 && MYSQL_VERSION_ID < 50000) || MYSQL_VERSION_ID >= 50003
+        mysql_library_init(0, 0, 0)
+# else
+        mysql_server_init(0, 0, 0)
+# endif
+       ) {
+        tqWarning("TQMYSQLDriver::qServerInit: unable to start server.");
     }
-    
 # endif // MYSQL_VERSION_ID
 #endif // Q_NO_MYSQL_EMBEDDED
+
+#if defined(MARIADB_BASE_VERSION) || defined(MARIADB_VERSION_ID)
+    tqAddPostRoutine(mysql_server_end);
+#endif
 }
 
 TQMYSQLDriver::TQMYSQLDriver( TQObject * parent, const char * name )
